import React, { useEffect, useState } from "react";
import { Button, Card, Switch, Table } from "antd";
import { ProTable } from "@ant-design/pro-components";
import { getTaMemberCard } from "@/services/taMemberCard";
import { queryTable } from "@/utils/request";
import moment from "moment";
import MemberOrderModal from "./MemberOrderModal";

export default (props) => {
  const { memberId } = props;
  const actionRef = React.useRef();

  const TaMemberCardList = queryTable(() =>
    getTaMemberCard({ memberId: memberId })
  );
  const [id, setId] = useState();
  const [open, setOpen] = useState(false);

  const columns = [
    {
      title: "开卡人姓名",
      dataIndex: "memberName",
    },
    {
      title: "手机号",
      dataIndex: "memberPhone",
    },
    {
      title: "总次数",
      dataIndex: "totalAmount",
    },
    {
      title: "剩余次数",
      dataIndex: "leftAmount",
    },
    {
      title: "开卡日期",
      dataIndex: "bizDate",
      render: (it) => (it ? moment(it).format("YYYY-MM-DD HH:mm:ss") : ""),
    },
    {
      title: "总时长",
      dataIndex: "totalTime",
    },
    {
      title: "截止日期",
      dataIndex: "expireTime",
      render: (it) => (it ? moment(it).format("YYYY-MM-DD HH:mm:ss") : ""),
    },
    { 
      title: "操作",
      valueType: "option",
      key: "option",
      ellipsis: true,
      render: (_, record) => [
        <Button
          style={{ padding: 0 }}
          type="link"
          key={1}
          onClick={() => onClickOpen(record)}
        >
          消费记录
        </Button>,
      ],
    },
  ];

  const onClickOpen = (val) => {
    setId(val?.cardId);
    setOpen(true);
  };

  const onCancel = () => {
    setOpen(false);
  };

  return (
    <>
      <ProTable
        actionRef={actionRef}
        rowKey="cardId"
        columns={columns}
        options={false}
        search={false}
        request={TaMemberCardList}
      />
      <MemberOrderModal open={open} onCancel={onCancel} id={id} />
    </>
  );
};
